package main.notepage;

import java.awt.Point;
import java.awt.Color;
import java.util.Iterator;
import java.util.Vector;

/**
 * A collection of data representing a drawn penstroke.
 * 
 * @author Wervyn
 * @version 1.0
 */
public class NotepageStroke extends NotepagePrimative {

	/**
	 * An identifier for this implementation class.
	 */
	public static final String CLASS_ID = "NotepageStroke";
	
	/** A list of coordinate points in the stroke. */
	private Vector<Point> coords;
	
	/** The width of the stroke. */
	private int penwidth;
	
	/** The color of the stroke. */
	private Color pencolor;
	
	/**
	 * Default constructor, initializes an empty stroke, width 1, black.
	 */
	public NotepageStroke() {
		this(new Vector<Point>(), 1, Color.black);	
	}
	
	/**
	 * Initialize a stroke with the given list of points, width 1, black.
	 * 
	 * @param coords A list of coordinate points that comprise the stroke.
	 */
	public NotepageStroke(Vector<Point> coords) {
		this(coords, 1, Color.black);
	}
	
	/**
	 * Initialize a stroke with the given list of points, width, and color.
	 * 
	 * @param coords A list of coordinate points that comprise the stroke.
	 * @param penwidth The width of the stroke.
	 * @param pencolor The color of the stroke.
	 */
	public NotepageStroke(Vector<Point> coords, int penwidth, Color pencolor) {
		super(NotepageStroke.CLASS_ID);
		setStroke(coords);
		setPenwidth(penwidth);
		setPencolor(pencolor);
	}
	
	/**
	 * Modifier for the points in the stroke.
	 * 
	 * @param coords A new list of points for the stroke.
	 */
	public void setStroke(Vector<Point> coords) {
		this.coords = coords;
	}

	/**
	 * Accessor for the points in the stroke.
	 * 
	 * @return The list of points in the stroke.
	 */
	public Vector<Point> getStroke() {
		return coords;
	}
	
	/**
	 * Modifier for the width of the stroke.
	 * 
	 * @param penwidth The new width of the stroke.
	 */
	public void setPenwidth(int penwidth) {
		this.penwidth = penwidth;
	}

	/**
	 * Accessor for the width of the stroke.
	 * 
	 * @return The width of the stroke.
	 */
	public int getPenwidth() {
		return penwidth;
	}

	/**
	 * Modifier for the color of the stroke.
	 * 
	 * @param pencolor The new color of the stroke.
	 */
	public void setPencolor(Color pencolor) {
		this.pencolor = pencolor;
	}

	/**
	 * Accessor for the color of the stroke.
	 * 
	 * @return The color of the stroke.
	 */
	public Color getPencolor() {
		return pencolor;
	}
	
	/**
	 * Add a new point to the end of the stroke list.
	 * 
	 * @param point A point to be added.
	 */
	public void addPoint(Point point) {
		coords.add(point);
	}
	
	/**
	 * Get the length of the stroke in terms of the number of points in it.
	 * 
	 * @return The size of the stroke list.
	 */
	public int size() {
		return coords.size();
	}
	
	/**
	 * Get an iterator to the list of points.
	 * 
	 * @return An iterator over the stroke list.
	 */
	public Iterator<Point> iterator() {
		return coords.iterator();
	}
}
