package main.notepage;

import java.awt.Color;
import java.awt.Font;
import java.awt.Point;

/**
 * A collection of data representing a field of text.
 * 
 * @author Wervyn
 * @version 1.0
 */
public class NotepageText extends NotepagePrimative {
	
	/**
	 * An identifier for this implementation class.
	 */
	public static final String CLASS_ID = "NotepageText";
	
	/** The text content of this text field. */
	private String text;
	
	/** The font of this text field. */
	private Font font;
	
	/** The font color of this text field. */
	private Color color;
	
	/** The current editing position within this text field (UNUSED) */
	private int position;
	
	/** The starting location of this text field.*/
	private Point location;
	
	/**
	 * Default constructor, initializes blank text, default font, black.
	 */
	public NotepageText() {
		this("",new Font("Arial", Font.PLAIN, 12), Color.black);
	}
	
	/**
	 * Initializes the text field with the given text, default font, black.
	 * 
	 * @param text The text content of the text field.
	 */
	public NotepageText(String text) {
		this(text, new Font("Arial", Font.PLAIN, 12), Color.black);
	}
	
	/**
	 * Initializes the text field with the given text, font, and color.
	 * 
	 * @param text The text content of the text field.
	 * @param font The font of the text field.
	 * @param color
	 */
	public NotepageText(String text, Font font, Color color) {
		super(NotepageText.CLASS_ID);
		setText(text);
		setFont(font);
		setColor(color);
		setLocation(new Point(0,0));
	}

	/**
	 * Modifier for the text.
	 * 
	 * @param text The new text for this text field.
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * Accessor for the text of the text field.
	 * 
	 * @return The text content of the text field.
	 */
	public String getText() {
		return text;
	}
	
	/**
	 * Add text to the end of the text field.
	 * 
	 * @param text The text to be added.
	 */
	public void addText(String text) {
		this.text += text;
	}

	/**
	 * Remove the last character of the text field.
	 */
	public void backspace() {
		if (size() > 0) {
			text = text.substring(0,text.length()-1);
		}
	}
	
	/**
	 * Modifier for the font of the text field.
	 * 
	 * @param font The new font of the text field.
	 */
	public void setFont(Font font) {
		this.font = font;
	}

	/**
	 * Accessor for the font of the text field.
	 * 
	 * @return The font of the text field.
	 */
	public Font getFont() {
		return font;
	}

	/**
	 * Modifier for the color of the text field.
	 * 
	 * @param color The new color of the text field.
	 */
	public void setColor(Color color) {
		this.color = color;
		
	}

	/**
	 * Accessor for the color of the text field.
	 * 
	 * @return The color of the text field.
	 */
	public Color getColor() {
		return this.color;
	}
	
	/**
	 * Modifier for the position in the text field. (UNUSED)
	 * 
	 * @param position The new position in the text field.
	 */
	public void setPosition(int position) {
		this.position = position;
	}

	/**
	 * Accessor for the position in the text field. (UNUSED)
	 * 
	 * @return The position in the text field.
	 */
	public int getPosition() {
		return position;
	}

	/**
	 * Modifier for the location of the text field.
	 * 
	 * @param location The new location of the text field.
	 */
	public void setLocation(Point location) {
		this.location = location;
	}

	/**
	 * Accessor for the location of the text field.
	 * 
	 * @return The location of the text field.
	 */
	public Point getLocation() {
		return location;
	}

	/**
	 * Get the size of the text with regard to the length of the string.
	 * 
	 * @return The length of the text content.
	 */
	public int size() {
		return text.length();
	}
}
